@@ -14,6 +14,7 @@ from nomnomdata.auth import NNDAuth
 from .util import NomitallSession
 
 _logger = logging.getLogger(__name__)
+client = docker.from_env()
 
 
 @click.command(name="deploy")
@@ -98,30 +99,31 @@ def deploy(buildp, mpath, dpath, nomitall, channel, dry_run, skip_confirm):
         raise Exception(
             "There was a problem connecting to the docker agent, ensure it is running and in a good state"
         ) from e
-    image, tag = build_engine(
-        engine_name=engine_name, client=client, tag=channel, docker_file=dpath,
+    build_engine(
+        engine_name=engine_name, channel=channel, docker_file=dpath,
     )
     if not dry_run:
-        deploy_engine(image, tag, data)
+        deploy_engine(engine_name, channel, data)
         if channel == "stable" and nomitall == "nomitall-prod":
-            deploy_engine(image, "prod", data)
+            client.api.tag(f"{engine_name}:stable", f"{engine_name}:prod")
+            deploy_engine(engine_name, "prod", data)
 
 
-def deploy_engine(image, tag, creds):
-    _logger.info("----Pushing image----")
-    client = docker.from_env()
+def deploy_engine(engine_name, channel, creds):
+    _logger.info(f"----Pushing image {engine_name}:{channel}----")
     auth_config = {"username": creds["user"], "password": creds["token"]}
-    _logger.info(f"Pushing {image}:{tag}")
-    push_logs = client.api.push(image, tag=tag, auth_config=auth_config, stream=True)
+    push_logs = client.api.push(
+        engine_name, tag=channel, auth_config=auth_config, stream=True
+    )
     deque(stream_output(push_logs, sys.stdout), maxlen=0)
     _logger.info("----Successfully pushed image----")
 
 
-def build_engine(engine_name, client, tag, docker_file, buildargs=None):
-    _logger.info("----Building image----")
+def build_engine(engine_name, channel, docker_file, buildargs=None):
+    _logger.info(f"----Building image {engine_name}:{channel}----")
     build_logs = client.api.build(
         dockerfile=docker_file,
-        tag=":".join([engine_name, tag]),
+        tag=f"{engine_name}:{channel}",
         rm=True,
         path=".",
         pull=True,
@@ -129,4 +131,3 @@ def build_engine(engine_name, client, tag, docker_file, buildargs=None):
     )
     deque(stream_output(build_logs, sys.stdout), maxlen=0)
     _logger.info("----Finished building image----")
-    return engine_name, tag
