@@ -1,5 +1,5 @@
 import logging
-from pprint import pformat
+from pprint import pformat, pprint
 
 from cerberus.validator import Validator
 
@@ -34,6 +34,7 @@ help_schema = {
 parameter_field_schema = {
     "help": help_schema.copy(),
     "collapsed": {"required": False, "type": "boolean"},
+    "many": {"required": False, "type": "boolean"},
     "required": {"required": False, "type": "boolean"},
     "choices": {"dependencies": {"type": ["enum", "enum_list"]}, "type": "list"},
     "default_choices": {"dependencies": {"type": ["enum_list"]}, "type": "list"},
@@ -61,7 +62,7 @@ parameter_field_schema = {
             {"allowed": ["code", "sql"], "dependencies": "dialect"},
             {"allowed": ["enum", "enum_list"], "dependencies": "choices"},
             # Add above bi-lateral dependencies as "forbidden" so above dependencies are evaluated only once.
-            {"forbidden": ["connection", "code", "sql", "enum", "enum_list"]},
+            {"forbidden": ["connection", "code", "sql", "enum", "enum_list", "nested"]},
         ],
     },
     "shared_config_type_uuid": {"type": "string", "required": False},
@@ -72,9 +73,19 @@ parameter_field_schema = {
     "default": {"required": False},
 }
 
+parameter_field_schema["parameters"] = {
+    "dependencies": {"type": ["nested"]},
+    "type": "list",
+    "schema": {"type": "dict", "schema": parameter_field_schema.copy()},
+}
+parameter_field_schema["type"]["allowed"].append("nested")
+parameter_field_schema["type"]["oneof"].insert(
+    0, {"allowed": ["nested"], "dependencies": "parameters"},
+)
+
 parameter_group_schema = {
     "display_name": {"type": "string", "required": True},
-    "collapsed": {"required": False, "type": "boolean",},
+    "collapsed": {"required": False, "type": "boolean"},
     "shared_parameter_group_uuid": {
         "required": False,
         "dependencies": {"type": ["group"]},
